//[mahjong-utils](../../../../index.md)/[mahjongutils.models](../../index.md)/[Wind](../index.md)/[North](index.md)

# North

[common]\
[North](index.md)

## Properties

| Name | Summary |
|---|---|
| [name](index.md#-372974862%2FProperties%2F1581026887) | [common]<br>val [name](index.md#-372974862%2FProperties%2F1581026887): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [ordinal](index.md#-739389684%2FProperties%2F1581026887) | [common]<br>val [ordinal](index.md#-739389684%2FProperties%2F1581026887): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |
| [tile](../tile.md) | [common]<br>val [tile](../tile.md): [Tile](../../-tile/index.md)<br>对应的风牌 |
